@@ -1,4 +1,5 @@
 import os
+import sys
 
 from PyQt5.QtCore import Qt, QDir
 from PyQt5.QtGui import QIcon, QPixmap, QGuiApplication
@@ -36,6 +37,26 @@ class GuiApp(App, QWidget):
         QApplication.instance().setQuitOnLastWindowClosed(not config.ENABLE_TRAY)
         QApplication.instance().setApplicationName('FeelUOwn')
 
+        if sys.platform == 'win32':
+            font = QApplication.font()
+            # By default, it uses SimSun(宋体) on windows, which is a little ugly.
+            # "Segoe UI Symbol" is used to render charactor symbols.
+            # "Microsoft Yahei" is used to render chinese (and english).
+            # Choose a default sans-serif font when the first two fonts do not work,
+            font.setFamilies(['Segoe UI Symbol', 'Microsoft YaHei', 'sans-serif'])
+
+            # When a HiDPI screen is used, users need to set both font DPI and
+            # screen scale factor to make it working properly when pointSize is used.
+            # It's hard for most users to set them right.
+            # When using pixelSize, users only need to set screen scale factor.
+            # In other words, only QT_AUTO_SCREEN_SCALE_FACTOR=1 is needed to set
+            # and feeluown can works properly in HiDPI environment.
+            #
+            # Based on past experience, 13px is the default font size for all platform,
+            # including windows, linux and macOS.
+            font.setPixelSize(13)
+            QApplication.setFont(font)
+
         QWidget.__init__(self)
         App.__init__(self, *args, **kwargs)
 
@@ -71,19 +92,29 @@ class GuiApp(App, QWidget):
         if self.config.ENABLE_TRAY:
             self.tray.initialize()
             self.tray.show()
-        self.tips_mgr.show_random_tip()
         self.coll_uimgr.initialize()
         self.watch_mgr.initialize()
         self.browser.initialize()
         QApplication.instance().aboutToQuit.connect(self.about_to_exit)
 
     def run(self):
-        super().run()
         self.show()
+        super().run()
 
-    def load_state(self):
-        super().load_state()
-        self.browser.goto(page='/player_playlist')
+    def apply_state(self, state):
+        super().apply_state(state)
+        coll_library = self.coll_uimgr.get_coll_library()
+        coll_id = self.coll_uimgr.get_coll_id(coll_library)
+        self.browser.goto(page=f'/colls/{coll_id}')
+
+        gui = state.get('gui', {})
+        lyric = gui.get('lyric', {})
+        self.ui.lyric_window.apply_state(lyric)
+
+    def dump_state(self):
+        state = super().dump_state()
+        state['gui'] = {'lyric': self.ui.lyric_window.dump_state()}
+        return state
 
     def closeEvent(self, _):
         if not self.config.ENABLE_TRAY:
