@@ -1,19 +1,16 @@
 import logging
 from PyQt5.QtWidgets import QSizePolicy, QSplitter, QVBoxLayout
 
-from feeluown.utils.utils import use_mpv_old
 from feeluown.gui.widgets.separator import Separator
 from feeluown.gui.widgets.settings import SettingsDialog
 from feeluown.gui.widgets.messageline import MessageLine
+from feeluown.gui.widgets.mpv import MpvOpenGLWidget
 
-if use_mpv_old():
-    from feeluown.gui.widgets.mpv_old import MpvOpenGLWidget
-else:
-    from feeluown.gui.widgets.mpv import MpvOpenGLWidget
-
+from feeluown.gui.uimain.lyric import LyricWindow
 from feeluown.gui.uimain.sidebar import LeftPanel
 from feeluown.gui.uimain.page_view import RightPanel
 from feeluown.gui.uimain.player_bar import TopPanel
+from feeluown.gui.uimain.playlist_overlay import PlaylistOverlay
 
 
 logger = logging.getLogger(__name__)
@@ -23,20 +20,26 @@ class Ui:
 
     def __init__(self, app):
         self._app = app
+        # Let the following widgets access ui object during init.
+        self._app.ui = self
         self._layout = QVBoxLayout(app)
-        self._top_separator = Separator(parent=app)
+        self._top_separator = Separator(app)
         self._splitter = QSplitter(app)
 
+        # Create widgets that don't rely on other widgets first.
+        self.lyric_window = LyricWindow(self._app)
+        self.lyric_window.hide()
+
         # NOTE: 以位置命名的部件应该只用来组织界面布局，不要
         # 给其添加任何功能性的函数
         self._message_line = MessageLine()
         self.top_panel = TopPanel(app, app)
-        self.sidebar = self._left_panel_con = LeftPanel(self._app,)
+        self.sidebar = self._left_panel_con = LeftPanel(self._app)
         self.left_panel = self._left_panel_con.p
         self.page_view = self.right_panel = RightPanel(self._app, self._splitter)
         self.toolbar = self.bottom_panel = self.right_panel.bottom_panel
         self.mpv_widget = MpvOpenGLWidget(self._app)
-        self.frameless_container = None
+        self.playlist_overlay = PlaylistOverlay(app, parent=app)
 
         # alias
         self.magicbox = self.bottom_panel.magicbox
@@ -49,14 +52,24 @@ class Ui:
         self.forward_btn = self.bottom_panel.forward_btn
         self.toggle_video_btn = self.pc_panel.toggle_video_btn
 
-        self.pc_panel.playlist_btn.clicked.connect(
-            lambda: self._app.browser.goto(page='/player_playlist'))
+        self.pc_panel.playlist_btn.clicked.connect(self.raise_playlist_view)
         self.toolbar.settings_btn.clicked.connect(
             self._open_settings_dialog)
         self.toolbar.toggle_sidebar_btn.clicked.connect(self._toggle_sidebar)
 
         self._setup_ui()
 
+    def raise_playlist_view(self):
+        if not self.playlist_overlay.isVisible():
+            width = max(self._app.width() // 4, 330)
+            x = self._app.width() - width
+            height = self._app.height()
+            self.playlist_overlay.setGeometry(x, 0, width, height)
+            self.playlist_overlay.show()
+            self.playlist_overlay.setFocus()
+            # Put the widget on top.
+            self.playlist_overlay.raise_()
+
     def _setup_ui(self):
         self._app.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
 
@@ -64,6 +77,7 @@ class Ui:
         self._splitter.addWidget(self._left_panel_con)
         self._splitter.addWidget(self.right_panel)
         self._message_line.hide()
+        self.playlist_overlay.hide()
 
         self.right_panel.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
 
@@ -79,7 +93,7 @@ class Ui:
         self.top_panel.layout().setSpacing(0)
         self.top_panel.layout().setContentsMargins(0, 0, 0, 0)
 
-        self._app.resize(880, 600)
+        self._app.resize(960, 600)
 
     def _open_settings_dialog(self):
         dialog = SettingsDialog(self._app, self._app)
