@@ -13,7 +13,6 @@ from feeluown.utils import aio
 from feeluown.excs import ProviderIOError
 from feeluown.media import MediaType
 from feeluown.player import State
-from feeluown.gui.widgets.lyric import Window as LyricWindow
 from feeluown.gui.widgets.menu import SongMenuInitializer
 from feeluown.gui.helpers import resize_font
 from feeluown.gui.widgets import TextButton
@@ -87,16 +86,17 @@ class WatchButton(TextButton):
 
 
 class LyricButton(TextButton):
-    def __init__(self, app, parent):
+    def __init__(self, app, parent: 'PlayerControlPanel'):
         super().__init__('词', parent=parent)
         self._app = app
 
         self.setCheckable(True)
         self.clicked.connect(self._toggle_lyric_window)
-        self.parent().lyric_window.installEventFilter(self)  # hack
+
+        self._app.ui.lyric_window.installEventFilter(self)
 
     def _toggle_lyric_window(self):
-        lyric_window = self._app.ui.player_bar.lyric_window
+        lyric_window = self._app.ui.lyric_window
         if lyric_window.isVisible():
             lyric_window.hide()
         else:
@@ -131,7 +131,7 @@ class SongBriefLabel(QLabel):
         self._timer.timeout.connect(self.change_text_position)
 
     def change_text_position(self):
-        if not self.parent().isVisible():
+        if not self.parent().isVisible():  # type: ignore
             self._timer.stop()
             self._pos = 0
             return
@@ -176,7 +176,7 @@ class SongBriefLabel(QLabel):
             QRect(self._pos, 0, self.width() - self._pos, self.height()),
             Qt.AlignLeft | Qt.AlignVCenter,
             self._txt
-        )
+        )  # type: ignore[call-overload]
 
     def contextMenuEvent(self, e):
         song = self._app.playlist.current_song
@@ -237,9 +237,6 @@ class PlayerControlPanel(QFrame):
             def __init__(self, *args, **kwargs):
                 super().__init__(*args, **kwargs)
 
-        self.lyric_window = LyricWindow()
-        self.lyric_window.hide()
-
         # initialize sub widgets
         self._layout = QHBoxLayout(self)
         self.previous_btn = IconButton(self)
@@ -304,9 +301,6 @@ class PlayerControlPanel(QFrame):
         player.state_changed.connect(self._on_player_state_changed, aioqueue=True)
         player.metadata_changed.connect(self.on_metadata_changed, aioqueue=True)
         player.volume_changed.connect(self.volume_btn.on_volume_changed)
-        self._app.live_lyric.sentence_changed.connect(self.lyric_window.set_sentence)
-        self.lyric_window.play_previous_needed.connect(playlist.previous)
-        self.lyric_window.play_next_needed.connect(playlist.next)
 
         self._setup_ui()
 
@@ -428,6 +422,11 @@ class PlayerControlPanel(QFrame):
         else:
             self.song_source_label.setText(default)
 
+        released = metadata.get('released', '')
+        if released:
+            self.cover_label.setToolTip(f'专辑发行日期：{released}')
+        else:
+            self.cover_label.setToolTip('')
         # Set song artwork.
         artwork = metadata.get('artwork', '')
         artwork_uid = metadata.get('uri', artwork)
